﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Encodings.PermutationEncoding;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Analysis.SolutionCaching.PermutationEncoding {
  [Item("PermutationSolutionCache", "Stores Permutation solutions generated by an algorithm.")]
  [StorableClass]
  public class PermutationSolutionCache : SolutionCache<Permutation, PermutationSolutionInformation> {
    [StorableConstructor]
    protected PermutationSolutionCache(bool deserializing) : base(deserializing) { }
    protected PermutationSolutionCache(PermutationSolutionCache original, Cloner cloner)
      : base(original, cloner) {
    }
    public PermutationSolutionCache() : base() { }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new PermutationSolutionCache(this, cloner);
    }

    protected override void InitializeSolutionDictionary() {
      solutionDictionary = new Dictionary<Permutation, List<PermutationSolutionInformation>>(new PermutationEqualityComparer());
    }
  }
}
